@@ -8,12 +8,10 @@ extern crate url;
 
 use crate::config::CFG;
 use crate::config::VIEWER_SERVED_MIME_TYPES_HMAP;
-use crate::filter::TERA;
 use crate::note::Note;
 use crate::viewer::error::ViewerError;
 use crate::viewer::init::LOCALHOST;
 use parse_hyperlinks::iterator_html::{Hyperlink, InlineImage};
-use parse_hyperlinks::renderer::text_rawlinks2html;
 use percent_encoding::percent_decode_str;
 use std::collections::HashSet;
 use std::fs;
@@ -29,7 +27,6 @@ use std::sync::mpsc::{channel, Receiver, Sender};
 use std::sync::{Arc, Mutex, RwLock};
 use std::thread;
 use std::time::SystemTime;
-use tera::Tera;
 use url::Url;
 
 /// The TCP stream is read in chunks. This is the read buffer size.
@@ -38,20 +35,20 @@ const TCP_READ_BUFFER_SIZE: usize = 512;
 /// Javascript client code, part 1
 /// Refresh on WTFiles events.
 pub const SSE_CLIENT_CODE1: &str = r#"
-var evtSource = new EventSource("http://"#;
+    var evtSource = new EventSource("http://"#;
 /// Javascript client code, part 2
 /// Save last scroll position into local storage.
 /// Jump to the last saved scroll position.
 pub const SSE_CLIENT_CODE2: &str = r#"/events");
-evtSource.addEventListener("update", function(e) {
-    localStorage.setItem('scrollPosition', window.scrollY);
-    window.location.reload(true);
-});
-window.addEventListener('load', function() {
-    if(localStorage.getItem('scrollPosition') !== null)
-        window.scrollTo(0, localStorage.getItem('scrollPosition'));
-});
-"#;
+    evtSource.addEventListener("update", function(e) {
+        localStorage.setItem('scrollPosition', window.scrollY);
+        window.location.reload(true);
+    });
+    window.addEventListener('load', function() {
+        if(localStorage.getItem('scrollPosition') !== null)
+            window.scrollTo(0, localStorage.getItem('scrollPosition'));
+    });
+    "#;
 
 /// Server-Sent-Event token to request a page update.
 const SSE_EVENT_TOKEN: &str = "update";
@@ -513,7 +510,7 @@ impl ServerThread {
 
     #[inline]
     /// Renders the error page with the `VIEWER_ERROR_TMPL`.
-    fn render_content_and_error(&self) -> Result<String, Box<dyn std::error::Error>> {
+    fn render_content_and_error(&self) -> Result<String, ViewerError> {
         // Deserialize.
         let js = format!(
             "{}{}:{}{}",
@@ -595,21 +592,11 @@ impl ServerThread {
             // page and return this instead.
             Err(e) => {
                 // Render error page providing all information we have.
-                let mut context = tera::Context::new();
-                let err = e.to_string();
-                context.insert("noteError", &err);
-                context.insert("file", &self.doc_path.to_str().unwrap_or_default());
-                // Java Script
-                context.insert("noteJS", &js);
-
-                let note_error_content = fs::read_to_string(&self.doc_path).unwrap_or_default();
-                let note_error_content = text_rawlinks2html(&note_error_content);
-                context.insert("noteErrorContent", note_error_content.trim());
-
-                let mut tera = Tera::default();
-                tera.extend(&TERA)?;
-                let html = tera.render_str(&CFG.viewer_error_tmpl, &context)?;
-                Ok(html)
+                Note::render_erroneous_content(&self.doc_path, &CFG.viewer_error_tmpl, &js, e)
+                    .map_err(|e| { ViewerError::RenderErrorPage {
+                        tmpl: "viewer_error_tmpl".to_string(),
+                        source: e,
+                    }})
             }
         }
     }
